@@ -1,18 +1,17 @@
-import pkg_resources
-
 from . import operations
 from .attrdict import AttrDict
-from .magic import MagicFilter, MagicT
+from .magic import MagicFilter, MagicT, RegexpMode
 
 __all__ = (
     "__version__",
     "operations",
     "MagicFilter",
     "MagicT",
+    "RegexpMode",
     "F",
     "AttrDict",
 )
 
-__version__ = pkg_resources.get_distribution(__name__).version
+__version__ = "1"
 
 F = MagicFilter()
